fqdn: Validates fully-qualified domain names against RFC 1123, so that they are acceptable to modern bowsers
============================================================================================================

Description
-----------

Validates fully-qualified domain names against RFC 1123, so that they are acceptable to modern bowsers

License
-------

MPL 2.0

Upstream Contact
----------------

https://pypi.org/project/fqdn/

